import * as React from 'react';
import { FieldInputProps, FieldMetaProps, FieldValidator, GenericFieldHTMLAttributes } from './types';
export declare function unstable_useFieldValue(name: string): any;
export declare function unstable_useFieldError(name: string): any;
export declare function unstable_useFieldTouched(name: string): any;
export interface StrictFieldProps<V = any> {
    field: FieldInputProps<V>;
    meta: FieldMetaProps<V>;
}
export interface UseStrictFieldProps<V = any> {
    /**
     * Component to render. Can either be a string e.g. 'select', 'input', or 'textarea', or a component.
     */
    as?: React.ComponentType<StrictFieldProps<V>['field']> | string | React.ComponentType | React.ForwardRefExoticComponent<any>;
    /**
     * Validate a single field value independently
     */
    validate?: FieldValidator;
    /**
     * Function to parse raw input value before setting it to state
     */
    parse?: (value: unknown, name: string) => V;
    /**
     * Function to transform value passed to input
     */
    format?: (value: V, name: string) => any;
    /**
     * Wait until blur event before formatting input value?
     * @default false
     */
    formatOnBlur?: boolean;
    /**
     * Field name
     */
    name: string;
    /** HTML input type */
    type?: string;
    /** Field value */
    value?: any;
    /** Inner ref */
    innerRef?: (instance: any) => void;
}
export declare type StrictFieldAttributes<T> = GenericFieldHTMLAttributes & UseStrictFieldProps<T> & T & {
    name: string;
};
export declare type StrictFieldHookConfig<T> = GenericFieldHTMLAttributes & UseStrictFieldProps<T>;
export declare type StrictFieldConfig<V = any> = UseStrictFieldProps<V> & {
    /**
     * Field component to render. Can either be a string like 'select' or a component.
     */
    component?: string | React.ComponentType<StrictFieldProps<V>> | React.ComponentType | React.ForwardRefExoticComponent<any>;
    /**
     * Render prop (works like React router's <Route render={props =>} />)
     * @deprecated
     */
    render?: (props: StrictFieldProps<V>) => React.ReactNode;
    /**
     * Children render function <Field name>{props => ...}</Field>)
     */
    children?: ((props: StrictFieldProps<V>) => React.ReactNode) | React.ReactNode;
};
export declare function unstable_useField<Value = any>(nameOrOptions: string | StrictFieldHookConfig<Value>): [FieldInputProps<Value>, FieldMetaProps<Value>];
export declare function unstable_StrictField({ render, children, as: is, // `as` is reserved in typescript lol
component, ...props }: StrictFieldAttributes<any>): any;
